# Bio data files

- **codons_translations.csv**: Table of the genetic code (AAA=>K, AAC=>N...)
- **complements.csv**: Gives the reverse complements of nucleotides, including degenerate IUPAC notation nucleotides (A=>T, C=>G, M=>K, R=>Y...)
- **iupac_notation.csv**: Gives the ATGC nucleotides associated with each letter of the IUPAC notation (A=>A, "C=>C", B=>CGT, D=>AGT)
- **nucleotide_to_regexpr.csv** Gives for each letter of the IUPAC alphabet all the letters of the IUPAC alphabet which could be a match (A=>A, W=>[ATW], H=>[ACHMTWY])